@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 from .literals import (
     CertificateStateType,
@@ -204,7 +204,7 @@ _RequiredAddIpRoutesRequestRequestTypeDef = TypedDict(
     "_RequiredAddIpRoutesRequestRequestTypeDef",
     {
         "DirectoryId": str,
-        "IpRoutes": List["IpRouteTypeDef"],
+        "IpRoutes": Sequence["IpRouteTypeDef"],
     },
 )
 _OptionalAddIpRoutesRequestRequestTypeDef = TypedDict(
@@ -235,7 +235,7 @@ AddTagsToResourceRequestRequestTypeDef = TypedDict(
     "AddTagsToResourceRequestRequestTypeDef",
     {
         "ResourceId": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -335,7 +335,7 @@ _OptionalConnectDirectoryRequestRequestTypeDef = TypedDict(
     {
         "ShortName": str,
         "Description": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -384,7 +384,7 @@ _OptionalCreateComputerRequestRequestTypeDef = TypedDict(
     "_OptionalCreateComputerRequestRequestTypeDef",
     {
         "OrganizationalUnitDistinguishedName": str,
-        "ComputerAttributes": List["AttributeTypeDef"],
+        "ComputerAttributes": Sequence["AttributeTypeDef"],
     },
     total=False,
 )
@@ -409,7 +409,7 @@ CreateConditionalForwarderRequestRequestTypeDef = TypedDict(
     {
         "DirectoryId": str,
         "RemoteDomainName": str,
-        "DnsIpAddrs": List[str],
+        "DnsIpAddrs": Sequence[str],
     },
 )
 
@@ -427,7 +427,7 @@ _OptionalCreateDirectoryRequestRequestTypeDef = TypedDict(
         "ShortName": str,
         "Description": str,
         "VpcSettings": "DirectoryVpcSettingsTypeDef",
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -469,7 +469,7 @@ _OptionalCreateMicrosoftADRequestRequestTypeDef = TypedDict(
         "ShortName": str,
         "Description": str,
         "Edition": DirectoryEditionType,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -531,7 +531,7 @@ _OptionalCreateTrustRequestRequestTypeDef = TypedDict(
     "_OptionalCreateTrustRequestRequestTypeDef",
     {
         "TrustType": TrustTypeType,
-        "ConditionalForwarderIpAddrs": List[str],
+        "ConditionalForwarderIpAddrs": Sequence[str],
         "SelectiveAuth": SelectiveAuthType,
     },
     total=False,
@@ -700,7 +700,7 @@ _RequiredDescribeConditionalForwardersRequestRequestTypeDef = TypedDict(
 _OptionalDescribeConditionalForwardersRequestRequestTypeDef = TypedDict(
     "_OptionalDescribeConditionalForwardersRequestRequestTypeDef",
     {
-        "RemoteDomainNames": List[str],
+        "RemoteDomainNames": Sequence[str],
     },
     total=False,
 )
@@ -724,7 +724,7 @@ DescribeConditionalForwardersResultTypeDef = TypedDict(
 DescribeDirectoriesRequestRequestTypeDef = TypedDict(
     "DescribeDirectoriesRequestRequestTypeDef",
     {
-        "DirectoryIds": List[str],
+        "DirectoryIds": Sequence[str],
         "NextToken": str,
         "Limit": int,
     },
@@ -749,7 +749,7 @@ _RequiredDescribeDomainControllersRequestRequestTypeDef = TypedDict(
 _OptionalDescribeDomainControllersRequestRequestTypeDef = TypedDict(
     "_OptionalDescribeDomainControllersRequestRequestTypeDef",
     {
-        "DomainControllerIds": List[str],
+        "DomainControllerIds": Sequence[str],
         "NextToken": str,
         "Limit": int,
     },
@@ -777,7 +777,7 @@ DescribeEventTopicsRequestRequestTypeDef = TypedDict(
     "DescribeEventTopicsRequestRequestTypeDef",
     {
         "DirectoryId": str,
-        "TopicNames": List[str],
+        "TopicNames": Sequence[str],
     },
     total=False,
 )
@@ -863,7 +863,7 @@ _RequiredDescribeSharedDirectoriesRequestRequestTypeDef = TypedDict(
 _OptionalDescribeSharedDirectoriesRequestRequestTypeDef = TypedDict(
     "_OptionalDescribeSharedDirectoriesRequestRequestTypeDef",
     {
-        "SharedDirectoryIds": List[str],
+        "SharedDirectoryIds": Sequence[str],
         "NextToken": str,
         "Limit": int,
     },
@@ -891,7 +891,7 @@ DescribeSnapshotsRequestRequestTypeDef = TypedDict(
     "DescribeSnapshotsRequestRequestTypeDef",
     {
         "DirectoryId": str,
-        "SnapshotIds": List[str],
+        "SnapshotIds": Sequence[str],
         "NextToken": str,
         "Limit": int,
     },
@@ -911,7 +911,7 @@ DescribeTrustsRequestRequestTypeDef = TypedDict(
     "DescribeTrustsRequestRequestTypeDef",
     {
         "DirectoryId": str,
-        "TrustIds": List[str],
+        "TrustIds": Sequence[str],
         "NextToken": str,
         "Limit": int,
     },
@@ -944,8 +944,8 @@ DirectoryConnectSettingsTypeDef = TypedDict(
     "DirectoryConnectSettingsTypeDef",
     {
         "VpcId": str,
-        "SubnetIds": List[str],
-        "CustomerDnsIps": List[str],
+        "SubnetIds": Sequence[str],
+        "CustomerDnsIps": Sequence[str],
         "CustomerUserName": str,
     },
 )
@@ -1013,7 +1013,7 @@ DirectoryVpcSettingsTypeDef = TypedDict(
     "DirectoryVpcSettingsTypeDef",
     {
         "VpcId": str,
-        "SubnetIds": List[str],
+        "SubnetIds": Sequence[str],
     },
 )
 
@@ -1469,7 +1469,7 @@ RemoveIpRoutesRequestRequestTypeDef = TypedDict(
     "RemoveIpRoutesRequestRequestTypeDef",
     {
         "DirectoryId": str,
-        "CidrIps": List[str],
+        "CidrIps": Sequence[str],
     },
 )
 
@@ -1484,7 +1484,7 @@ RemoveTagsFromResourceRequestRequestTypeDef = TypedDict(
     "RemoveTagsFromResourceRequestRequestTypeDef",
     {
         "ResourceId": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1680,7 +1680,7 @@ UpdateConditionalForwarderRequestRequestTypeDef = TypedDict(
     {
         "DirectoryId": str,
         "RemoteDomainName": str,
-        "DnsIpAddrs": List[str],
+        "DnsIpAddrs": Sequence[str],
     },
 )
 
